package
Version:
v0.0.0-...-4b2ecaa
Opens a new window with list of versions in this module.
Published: Oct 24, 2020
License: Apache-2.0
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Groups struct {
Name string `yaml:"name"`
Rules []Rules `yaml:"rules"`
}
type Labels struct {
Prometheus string `yaml:"prometheus"`
Role string `yaml:"role"`
}
type Metadata struct {
Labels Labels `yaml:"labels"`
Name string `yaml:"name"`
}
type PrometheusRule struct {
APIVersion string `yaml:"apiVersion"`
Kind string `yaml:"kind"`
Metadata Metadata `yaml:"metadata"`
Spec Spec `yaml:"spec"`
}
type RecordingRule struct {
Groups []Groups `yaml:"groups"`
}
type Rules struct {
Expr string `yaml:"expr"`
Record string `yaml:"record"`
}
type Spec struct {
Groups []Groups `yaml:"groups"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.